==> jsf-impl-2.2.0-jbossorg-2-sources.jar: com/sun/faces/config/processor/ConfigProcessor.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.faces.config.processor;

import com.sun.faces.config.DocumentInfo;

import javax.servlet.ServletContext;

/**
 * <p>
 *  This interface provides a CoR structure for procesing JSF configuration
 *  resources.
 * </p>
 */
public interface ConfigProcessor {

    /**
     * <p>
     *   Set the next <code>ConfigProcessor</code> to be invoked once
     *   {@link ConfigProcessor#process(javax.servlet.ServletContext,com.sun.faces.config.DocumentInfo[])}
     *   has completed.
     * </p>
     *
     * @param nextProcessor the next processor in the chain to be invoked
     */
    public void setNext(ConfigProcessor nextProcessor);

    /**
     * <p>Return the next config processor in the chain, or null.</p>
     * 
     */
    public ConfigProcessor getNext();
    
    /*
     * Called to initialize the per-application metadata used by the ConfigProcessor
     */
    
    public void initializeClassMetadataMap(ServletContext sc);

    /**
     * <p>
     *  Process the array of <code>Document</code>s.
     * </p>
     *
     * @param sc the <code>ServletContext</code> for the application being configured
     * @param documentInfos  @throws Exception if an error occurs during processing
     */
    public void process(ServletContext sc, DocumentInfo[] documentInfos)
    throws Exception;


    /**
     * <p>
     *  Invoke the <code>ConfigProcess</code> specified by
     *  a call to {@link ConfigProcessor#setNext(ConfigProcessor)}, if any.
     * </p>
     * @param sc the <code>ServletContext</code> for the application being configured
     * @param documentInfos  @throws Exception if an error occurs invoking the next processor
     */
    public void invokeNext(ServletContext sc, DocumentInfo[] documentInfos)
    throws Exception;

}

==> jsf-impl-2.2.12-jbossorg-2-sources.jar: com/sun/faces/config/processor/ConfigProcessor.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.faces.config.processor;

import com.sun.faces.config.DocumentInfo;

import javax.servlet.ServletContext;

/**
 * <p>
 *  This interface provides a CoR structure for processing JSF configuration
 *  resources.
 * </p>
 */
public interface ConfigProcessor {

    /**
     * <p>
     *   Set the next <code>ConfigProcessor</code> to be invoked once
     *   {@link ConfigProcessor#process(javax.servlet.ServletContext,com.sun.faces.config.DocumentInfo[])}
     *   has completed.
     * </p>
     *
     * @param nextProcessor the next processor in the chain to be invoked
     */
    public void setNext(ConfigProcessor nextProcessor);

    /**
     * <p>Return the next config processor in the chain, or null.</p>
     * 
     */
    public ConfigProcessor getNext();
    
    /*
     * Called to initialize the per-application metadata used by the ConfigProcessor
     */
    
    public void initializeClassMetadataMap(ServletContext sc);

    /**
     * <p>
     *  Process the array of <code>Document</code>s.
     * </p>
     *
     * @param sc the <code>ServletContext</code> for the application being configured
     * @param documentInfos  @throws Exception if an error occurs during processing
     */
    public void process(ServletContext sc, DocumentInfo[] documentInfos)
    throws Exception;

    public void destroy(ServletContext sc);
    
    /**
     * <p>
     *  Invoke the <code>ConfigProcess</code> specified by
     *  a call to {@link ConfigProcessor#setNext(ConfigProcessor)}, if any.
     * </p>
     * @param sc the <code>ServletContext</code> for the application being configured
     * @param documentInfos  @throws Exception if an error occurs invoking the next processor
     */
    public void invokeNext(ServletContext sc, DocumentInfo[] documentInfos)
    throws Exception;
    
    public void destroyNext(ServletContext sc);

}
